@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::GitHub::Create;
 {
-  $Dist::Zilla::Plugin::GitHub::Create::VERSION = '0.15';
+  $Dist::Zilla::Plugin::GitHub::Create::VERSION = '0.16';
 }
 
 use Moose;
@@ -37,13 +37,18 @@ Dist::Zilla::Plugin::GitHub::Create - Create GitHub repo on dzil new
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
 Configure git with your GitHub credentials:
 
     $ git config --global github.user LoginName
+    $ git config --global github.password GitHubPassword
+
+Alternatively, the GitHub login token can be used instead of the password
+(note that token-based login has been deprecated by GitHub):
+
     $ git config --global github.token GitHubToken
 
 then, in your F<profile.ini>:
@@ -69,30 +74,33 @@ sub after_mint {
 
 	my $repo_name	= basename($opts -> {'mint_root'});
 
-	my $login = `git config github.user`;  chomp $login;
-	my $token = `git config github.token`; chomp $token;
-
-	if (!$login or !$token) {
-		$self -> log("Err: Provide valid GitHub login values");
-		return;
-	}
+	my ($login, $pass, $token)  = $self -> _get_credentials(0);
 
 	my $http = HTTP::Tiny -> new;
 
 	$self -> log("Creating new GitHub repository '$repo_name'");
 
-	push my @params, "login=$login", "token=$token";
+	my @params;
 
-	push @params,
-		"login=$login",
-		"token=$token",
-		"name=$repo_name",
-		'public='.$self -> public;
+	push @params, "login=$login", "token=$token" if $token;
+	push @params, "name=$repo_name", 'public='.$self -> public;
 
 	my $url 	= $self -> api.'/repos/create';
+
+	my $headers	= {
+		'content-type' => 'application/x-www-form-urlencoded'
+	};
+
+	if ($pass) {
+		require MIME::Base64;
+
+		my $basic = MIME::Base64::encode_base64("$login:$pass", '');
+		$headers -> {'authorization'} = "Basic $basic";
+	}
+
 	my $response	= $http -> request('POST', $url, {
 		content => join("&", @params),
-		headers => {'content-type' => 'application/x-www-form-urlencoded'}
+		headers => $headers
 	});
 
 	if ($response -> {'status'} == 401) {
